==> cljs-emotion-2021-02-15.1.0.jar: public/js/devcards/cljs-runtime/dv.cljs_emotion.js <==
goog.provide('dv.cljs_emotion');
var module$node_modules$react$index=shadow.js.require("module$node_modules$react$index", {});
var module$node_modules$$emotion$hash$dist$hash_browser_cjs=shadow.js.require("module$node_modules$$emotion$hash$dist$hash_browser_cjs", {});
var module$node_modules$$emotion$styled$dist$emotion_styled_browser_cjs=shadow.js.require("module$node_modules$$emotion$styled$dist$emotion_styled_browser_cjs", {});
var module$node_modules$$emotion$react$dist$emotion_react_browser_cjs=shadow.js.require("module$node_modules$$emotion$react$dist$emotion_react_browser_cjs", {});
dv.cljs_emotion.emotion_hash = goog.object.get(module$node_modules$$emotion$hash$dist$hash_browser_cjs,"default");
dv.cljs_emotion.styled_STAR_ = goog.object.get(module$node_modules$$emotion$styled$dist$emotion_styled_browser_cjs,"default");
console.log("STYLED: ",dv.cljs_emotion.styled_STAR_);
/**
 * Utility function that will force a lazy sequence of children (recursively) into realized
 *   vectors (React cannot deal with lazy seqs in production mode)
 */
dv.cljs_emotion.force_children = (function dv$cljs_emotion$force_children(x){
if(cljs.core.seq_QMARK_(x)){
return cljs.core.to_array(cljs.core.mapv.cljs$core$IFn$_invoke$arity$2(dv.cljs_emotion.force_children,x));
} else {
return x;
}
});
dv.cljs_emotion.keyframes = (function dv$cljs_emotion$keyframes(anim_map){
return module$node_modules$$emotion$react$dist$emotion_react_browser_cjs.keyframes(cljs.core.clj__GT_js(anim_map));
});
dv.cljs_emotion.kebab__GT_camel = (function dv$cljs_emotion$kebab__GT_camel(prop){
if(clojure.string.starts_with_QMARK_(prop,".")){
return prop;
} else {
if(clojure.string.includes_QMARK_(prop,"-")){
var words = cljs.core.mapv.cljs$core$IFn$_invoke$arity$2(clojure.string.capitalize,cljs.core.re_seq(/[a-zA-Z]+/,prop));
return clojure.string.join.cljs$core$IFn$_invoke$arity$1(cljs.core.update.cljs$core$IFn$_invoke$arity$3(words,(0),clojure.string.lower_case));
} else {
return prop;
}
}
});
/**
 * Also replaces styled components with their css classname is key position.
 */
dv.cljs_emotion.camelize_keys = (function dv$cljs_emotion$camelize_keys(style_map){
return clojure.walk.postwalk((function dv$cljs_emotion$camelize_keys_$_in_walk(v){
if((v instanceof cljs.core.Keyword)){
return dv.cljs_emotion.kebab__GT_camel(cljs.core.name(v));
} else {
if(cljs.core.truth_((function (){var and__4115__auto__ = cljs.core.meta(v);
if(cljs.core.truth_(and__4115__auto__)){
return cljs.core.contains_QMARK_(cljs.core.meta(v),new cljs.core.Keyword("dv.cljs-emotion","hashed-name","dv.cljs-emotion/hashed-name",-795044661));
} else {
return and__4115__auto__;
}
})())){
return [".",cljs.core.str.cljs$core$IFn$_invoke$arity$1(new cljs.core.Keyword("dv.cljs-emotion","hashed-name","dv.cljs-emotion/hashed-name",-795044661).cljs$core$IFn$_invoke$arity$1(cljs.core.meta(v)))].join('');
} else {
return v;

}
}
}),style_map);
});
/**
 * @define {string}
 */
dv.cljs_emotion.ADD_CLASSNAMES = goog.define("dv.cljs_emotion.ADD_CLASSNAMES","INITIAL");
dv.cljs_emotion.add_class_names_QMARK_ = (function dv$cljs_emotion$add_class_names_QMARK_(){
if(cljs.core.boolean_QMARK_(dv.cljs_emotion.ADD_CLASSNAMES)){
return dv.cljs_emotion.ADD_CLASSNAMES;
} else {
return goog.DEBUG;
}
});
dv.cljs_emotion.add_class_name = (function dv$cljs_emotion$add_class_name(props,class_name){
if(cljs.core.object_QMARK_(props)){
var G__56936 = props;
goog.object.set(G__56936,"className",clojure.string.trim(clojure.string.join.cljs$core$IFn$_invoke$arity$2(" ",new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [class_name,goog.object.get(props,"className")], null))));

return G__56936;
} else {
return cljs.core.update.cljs$core$IFn$_invoke$arity$3(props,new cljs.core.Keyword(null,"className","className",-1983287057),(function (p1__56935_SHARP_){
if((p1__56935_SHARP_ == null)){
return class_name;
} else {
return [cljs.core.str.cljs$core$IFn$_invoke$arity$1(class_name)," ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(p1__56935_SHARP_)].join('');
}
}));
}
});
dv.cljs_emotion.hashit = (function dv$cljs_emotion$hashit(string){
return ["dvcss-",cljs.core.str.cljs$core$IFn$_invoke$arity$1((dv.cljs_emotion.emotion_hash.cljs$core$IFn$_invoke$arity$1 ? dv.cljs_emotion.emotion_hash.cljs$core$IFn$_invoke$arity$1(string) : dv.cljs_emotion.emotion_hash.call(null,string)))].join('');
});
dv.cljs_emotion.set_class_name = (function dv$cljs_emotion$set_class_name(props,class_name){
if(cljs.core.truth_(class_name)){
var hashed_name = dv.cljs_emotion.hashit(class_name);
var props__$1 = dv.cljs_emotion.add_class_name(props,hashed_name);
if(cljs.core.truth_(dv.cljs_emotion.add_class_names_QMARK_())){
return dv.cljs_emotion.add_class_name(props__$1,class_name);
} else {
return props__$1;
}
} else {
return props;
}
});
dv.cljs_emotion.react_factory = (function dv$cljs_emotion$react_factory(el,class_name){
return (function() {
var G__56941 = null;
var G__56941__0 = (function (){
return module$node_modules$react$index.createElement(el,cljs.core.clj__GT_js(dv.cljs_emotion.set_class_name(cljs.core.PersistentArrayMap.EMPTY,class_name)));
});
var G__56941__1 = (function (props){
try{if(cljs.core.truth_((function (){var or__4126__auto__ = module$node_modules$react$index.isValidElement(props);
if(cljs.core.truth_(or__4126__auto__)){
return or__4126__auto__;
} else {
return typeof props === 'string';
}
})())){
return module$node_modules$react$index.createElement(el,dv.cljs_emotion.set_class_name(({}),class_name),props);
} else {
if(cljs.core.map_QMARK_(props)){
var props__$1 = cljs.core.clj__GT_js(dv.cljs_emotion.set_class_name(props,class_name));
return module$node_modules$react$index.createElement(el,props__$1);
} else {
if(cljs.core.object_QMARK_(props)){
return module$node_modules$react$index.createElement(el,dv.cljs_emotion.set_class_name(props,class_name));
} else {
if(((cljs.core.array_QMARK_(props)) || (cljs.core.coll_QMARK_(props)))){
return module$node_modules$react$index.createElement(el,dv.cljs_emotion.set_class_name(({}),class_name),dv.cljs_emotion.force_children(props));
} else {
return module$node_modules$react$index.createElement(el,dv.cljs_emotion.set_class_name(({}),class_name));

}
}
}
}
}catch (e56937){if((e56937 instanceof Object)){
var e = e56937;
return console.error("Error invoking an emotion styled component: ",e);
} else {
throw e56937;

}
}});
var G__56941__2 = (function() { 
var G__56942__delegate = function (props,children){
if(((((cljs.core.object_QMARK_(props)) && (cljs.core.not(module$node_modules$react$index.isValidElement(props))))) || (cljs.core.map_QMARK_(props)))){
var props__$1 = cljs.core.clj__GT_js(dv.cljs_emotion.set_class_name(props,class_name));
if(cljs.core.seq(children)){
return cljs.core.apply.cljs$core$IFn$_invoke$arity$4(module$node_modules$react$index.createElement,el,props__$1,dv.cljs_emotion.force_children(children));
} else {
return module$node_modules$react$index.createElement(el,props__$1);
}
} else {
return cljs.core.apply.cljs$core$IFn$_invoke$arity$4(module$node_modules$react$index.createElement,el,dv.cljs_emotion.set_class_name(({}),class_name),dv.cljs_emotion.force_children(cljs.core.list_STAR_.cljs$core$IFn$_invoke$arity$2(props,children)));
}
};
var G__56942 = function (props,var_args){
var children = null;
if (arguments.length > 1) {
var G__56948__i = 0, G__56948__a = new Array(arguments.length -  1);
while (G__56948__i < G__56948__a.length) {G__56948__a[G__56948__i] = arguments[G__56948__i + 1]; ++G__56948__i;}
  children = new cljs.core.IndexedSeq(G__56948__a,0,null);
} 
return G__56942__delegate.call(this,props,children);};
G__56942.cljs$lang$maxFixedArity = 1;
G__56942.cljs$lang$applyTo = (function (arglist__56949){
var props = cljs.core.first(arglist__56949);
var children = cljs.core.rest(arglist__56949);
return G__56942__delegate(props,children);
});
G__56942.cljs$core$IFn$_invoke$arity$variadic = G__56942__delegate;
return G__56942;
})()
;
G__56941 = function(props,var_args){
var children = var_args;
switch(arguments.length){
case 0:
return G__56941__0.call(this);
case 1:
return G__56941__1.call(this,props);
default:
var G__56950 = null;
if (arguments.length > 1) {
var G__56951__i = 0, G__56951__a = new Array(arguments.length -  1);
while (G__56951__i < G__56951__a.length) {G__56951__a[G__56951__i] = arguments[G__56951__i + 1]; ++G__56951__i;}
G__56950 = new cljs.core.IndexedSeq(G__56951__a,0,null);
}
return G__56941__2.cljs$core$IFn$_invoke$arity$variadic(props, G__56950);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
G__56941.cljs$lang$maxFixedArity = 1;
G__56941.cljs$lang$applyTo = G__56941__2.cljs$lang$applyTo;
G__56941.cljs$core$IFn$_invoke$arity$0 = G__56941__0;
G__56941.cljs$core$IFn$_invoke$arity$1 = G__56941__1;
G__56941.cljs$core$IFn$_invoke$arity$variadic = G__56941__2.cljs$core$IFn$_invoke$arity$variadic;
return G__56941;
})()
});
dv.cljs_emotion.global_STAR_ = dv.cljs_emotion.react_factory(module$node_modules$$emotion$react$dist$emotion_react_browser_cjs.Global,null);
dv.cljs_emotion.global_style = (function dv$cljs_emotion$global_style(props){
return dv.cljs_emotion.global_STAR_(new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"styles","styles",1954480375),dv.cljs_emotion.camelize_keys(props)], null));
});
dv.cljs_emotion.theme_provider = (function dv$cljs_emotion$theme_provider(var_args){
var args__4742__auto__ = [];
var len__4736__auto___56952 = arguments.length;
var i__4737__auto___56953 = (0);
while(true){
if((i__4737__auto___56953 < len__4736__auto___56952)){
args__4742__auto__.push((arguments[i__4737__auto___56953]));

var G__56954 = (i__4737__auto___56953 + (1));
i__4737__auto___56953 = G__56954;
continue;
} else {
}
break;
}

var argseq__4743__auto__ = ((((1) < args__4742__auto__.length))?(new cljs.core.IndexedSeq(args__4742__auto__.slice((1)),(0),null)):null);
return dv.cljs_emotion.theme_provider.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__4743__auto__);
});

(dv.cljs_emotion.theme_provider.cljs$core$IFn$_invoke$arity$variadic = (function (props,children){
if(cljs.core.contains_QMARK_(props,new cljs.core.Keyword(null,"theme","theme",-1247880880))){
} else {
throw (new Error("You must pass a :theme to the theme-provider."));
}

return cljs.core.apply.cljs$core$IFn$_invoke$arity$4(module$node_modules$react$index.createElement,module$node_modules$$emotion$react$dist$emotion_react_browser_cjs.ThemeProvider,cljs.core.clj__GT_js(props),dv.cljs_emotion.force_children(children));
}));

(dv.cljs_emotion.theme_provider.cljs$lang$maxFixedArity = (1));

/** @this {Function} */
(dv.cljs_emotion.theme_provider.cljs$lang$applyTo = (function (seq56939){
var G__56940 = cljs.core.first(seq56939);
var seq56939__$1 = cljs.core.next(seq56939);
var self__4723__auto__ = this;
return self__4723__auto__.cljs$core$IFn$_invoke$arity$variadic(G__56940,seq56939__$1);
}));


//# sourceMappingURL=dv.cljs_emotion.js.map

==> cljs-emotion-2021-02-15.2.0.jar: public/js/devcards/cljs-runtime/dv.cljs_emotion.js <==
goog.provide('dv.cljs_emotion');
var module$node_modules$react$index=shadow.js.require("module$node_modules$react$index", {});
var module$node_modules$$emotion$hash$dist$hash_browser_cjs=shadow.js.require("module$node_modules$$emotion$hash$dist$hash_browser_cjs", {});
var module$node_modules$$emotion$styled$dist$emotion_styled_browser_cjs=shadow.js.require("module$node_modules$$emotion$styled$dist$emotion_styled_browser_cjs", {});
var module$node_modules$$emotion$react$dist$emotion_react_browser_cjs=shadow.js.require("module$node_modules$$emotion$react$dist$emotion_react_browser_cjs", {});
dv.cljs_emotion.emotion_hash = goog.object.get(module$node_modules$$emotion$hash$dist$hash_browser_cjs,"default");
dv.cljs_emotion.styled = goog.object.get(module$node_modules$$emotion$styled$dist$emotion_styled_browser_cjs,"default");
/**
 * Utility function that will force a lazy sequence of children (recursively) into realized
 *   vectors (React cannot deal with lazy seqs in production mode)
 */
dv.cljs_emotion.force_children = (function dv$cljs_emotion$force_children(x){
if(cljs.core.seq_QMARK_(x)){
return cljs.core.to_array(cljs.core.mapv.cljs$core$IFn$_invoke$arity$2(dv.cljs_emotion.force_children,x));
} else {
return x;
}
});
dv.cljs_emotion.kebab__GT_camel = (function dv$cljs_emotion$kebab__GT_camel(prop){
if(clojure.string.starts_with_QMARK_(prop,".")){
return prop;
} else {
if(clojure.string.includes_QMARK_(prop,"-")){
var words = cljs.core.mapv.cljs$core$IFn$_invoke$arity$2(clojure.string.capitalize,cljs.core.re_seq(/[a-zA-Z]+/,prop));
return clojure.string.join.cljs$core$IFn$_invoke$arity$1(cljs.core.update.cljs$core$IFn$_invoke$arity$3(words,(0),clojure.string.lower_case));
} else {
return prop;
}
}
});
/**
 * Also replaces styled components with their css classname is key position.
 */
dv.cljs_emotion.camelize_keys = (function dv$cljs_emotion$camelize_keys(style_map){
return clojure.walk.postwalk((function dv$cljs_emotion$camelize_keys_$_in_walk(v){
if((v instanceof cljs.core.Keyword)){
return dv.cljs_emotion.kebab__GT_camel(cljs.core.name(v));
} else {
if(cljs.core.truth_((function (){var and__4115__auto__ = cljs.core.meta(v);
if(cljs.core.truth_(and__4115__auto__)){
return cljs.core.contains_QMARK_(cljs.core.meta(v),new cljs.core.Keyword("dv.cljs-emotion","hashed-name","dv.cljs-emotion/hashed-name",-795044661));
} else {
return and__4115__auto__;
}
})())){
return [".",cljs.core.str.cljs$core$IFn$_invoke$arity$1(new cljs.core.Keyword("dv.cljs-emotion","hashed-name","dv.cljs-emotion/hashed-name",-795044661).cljs$core$IFn$_invoke$arity$1(cljs.core.meta(v)))].join('');
} else {
return v;

}
}
}),style_map);
});
dv.cljs_emotion.keyframes = (function dv$cljs_emotion$keyframes(anim_map){
return module$node_modules$$emotion$react$dist$emotion_react_browser_cjs.keyframes(cljs.core.clj__GT_js(dv.cljs_emotion.camelize_keys(anim_map)));
});
/**
 * @define {string}
 */
dv.cljs_emotion.ADD_CLASSNAMES = goog.define("dv.cljs_emotion.ADD_CLASSNAMES","INITIAL");
dv.cljs_emotion.add_class_names_QMARK_ = (function dv$cljs_emotion$add_class_names_QMARK_(){
if(cljs.core.boolean_QMARK_(dv.cljs_emotion.ADD_CLASSNAMES)){
return dv.cljs_emotion.ADD_CLASSNAMES;
} else {
return goog.DEBUG;
}
});
dv.cljs_emotion.add_class_name = (function dv$cljs_emotion$add_class_name(props,class_name){
if(cljs.core.object_QMARK_(props)){
var G__45115 = props;
goog.object.set(G__45115,"className",clojure.string.trim(clojure.string.join.cljs$core$IFn$_invoke$arity$2(" ",new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [class_name,goog.object.get(props,"className")], null))));

return G__45115;
} else {
return cljs.core.update.cljs$core$IFn$_invoke$arity$3(props,new cljs.core.Keyword(null,"className","className",-1983287057),(function (p1__45114_SHARP_){
if((p1__45114_SHARP_ == null)){
return class_name;
} else {
return [cljs.core.str.cljs$core$IFn$_invoke$arity$1(class_name)," ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(p1__45114_SHARP_)].join('');
}
}));
}
});
dv.cljs_emotion.hashit = (function dv$cljs_emotion$hashit(string){
return ["dvcss-",cljs.core.str.cljs$core$IFn$_invoke$arity$1((dv.cljs_emotion.emotion_hash.cljs$core$IFn$_invoke$arity$1 ? dv.cljs_emotion.emotion_hash.cljs$core$IFn$_invoke$arity$1(string) : dv.cljs_emotion.emotion_hash.call(null,string)))].join('');
});
dv.cljs_emotion.set_class_name = (function dv$cljs_emotion$set_class_name(props,class_name){
if(cljs.core.truth_(class_name)){
var hashed_name = dv.cljs_emotion.hashit(class_name);
var props__$1 = dv.cljs_emotion.add_class_name(props,hashed_name);
if(cljs.core.truth_(dv.cljs_emotion.add_class_names_QMARK_())){
return dv.cljs_emotion.add_class_name(props__$1,class_name);
} else {
return props__$1;
}
} else {
return props;
}
});
dv.cljs_emotion.react_factory = (function dv$cljs_emotion$react_factory(el,class_name){
return (function() {
var G__45211 = null;
var G__45211__0 = (function (){
return module$node_modules$react$index.createElement(el,cljs.core.clj__GT_js(dv.cljs_emotion.set_class_name(cljs.core.PersistentArrayMap.EMPTY,class_name)));
});
var G__45211__1 = (function (props){
try{if(cljs.core.truth_((function (){var or__4126__auto__ = module$node_modules$react$index.isValidElement(props);
if(cljs.core.truth_(or__4126__auto__)){
return or__4126__auto__;
} else {
return typeof props === 'string';
}
})())){
return module$node_modules$react$index.createElement(el,dv.cljs_emotion.set_class_name(({}),class_name),props);
} else {
if(cljs.core.map_QMARK_(props)){
var props__$1 = cljs.core.clj__GT_js(dv.cljs_emotion.set_class_name(props,class_name));
return module$node_modules$react$index.createElement(el,props__$1);
} else {
if(cljs.core.object_QMARK_(props)){
return module$node_modules$react$index.createElement(el,dv.cljs_emotion.set_class_name(props,class_name));
} else {
if(((cljs.core.array_QMARK_(props)) || (cljs.core.coll_QMARK_(props)))){
return module$node_modules$react$index.createElement(el,dv.cljs_emotion.set_class_name(({}),class_name),dv.cljs_emotion.force_children(props));
} else {
return module$node_modules$react$index.createElement(el,dv.cljs_emotion.set_class_name(({}),class_name));

}
}
}
}
}catch (e45122){if((e45122 instanceof Object)){
var e = e45122;
return console.error("Error invoking an emotion styled component: ",e);
} else {
throw e45122;

}
}});
var G__45211__2 = (function() { 
var G__45217__delegate = function (props,children){
if(((((cljs.core.object_QMARK_(props)) && (cljs.core.not(module$node_modules$react$index.isValidElement(props))))) || (cljs.core.map_QMARK_(props)))){
var props__$1 = cljs.core.clj__GT_js(dv.cljs_emotion.set_class_name(props,class_name));
if(cljs.core.seq(children)){
return cljs.core.apply.cljs$core$IFn$_invoke$arity$4(module$node_modules$react$index.createElement,el,props__$1,dv.cljs_emotion.force_children(children));
} else {
return module$node_modules$react$index.createElement(el,props__$1);
}
} else {
return cljs.core.apply.cljs$core$IFn$_invoke$arity$4(module$node_modules$react$index.createElement,el,dv.cljs_emotion.set_class_name(({}),class_name),dv.cljs_emotion.force_children(cljs.core.list_STAR_.cljs$core$IFn$_invoke$arity$2(props,children)));
}
};
var G__45217 = function (props,var_args){
var children = null;
if (arguments.length > 1) {
var G__45219__i = 0, G__45219__a = new Array(arguments.length -  1);
while (G__45219__i < G__45219__a.length) {G__45219__a[G__45219__i] = arguments[G__45219__i + 1]; ++G__45219__i;}
  children = new cljs.core.IndexedSeq(G__45219__a,0,null);
} 
return G__45217__delegate.call(this,props,children);};
G__45217.cljs$lang$maxFixedArity = 1;
G__45217.cljs$lang$applyTo = (function (arglist__45220){
var props = cljs.core.first(arglist__45220);
var children = cljs.core.rest(arglist__45220);
return G__45217__delegate(props,children);
});
G__45217.cljs$core$IFn$_invoke$arity$variadic = G__45217__delegate;
return G__45217;
})()
;
G__45211 = function(props,var_args){
var children = var_args;
switch(arguments.length){
case 0:
return G__45211__0.call(this);
case 1:
return G__45211__1.call(this,props);
default:
var G__45222 = null;
if (arguments.length > 1) {
var G__45223__i = 0, G__45223__a = new Array(arguments.length -  1);
while (G__45223__i < G__45223__a.length) {G__45223__a[G__45223__i] = arguments[G__45223__i + 1]; ++G__45223__i;}
G__45222 = new cljs.core.IndexedSeq(G__45223__a,0,null);
}
return G__45211__2.cljs$core$IFn$_invoke$arity$variadic(props, G__45222);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
G__45211.cljs$lang$maxFixedArity = 1;
G__45211.cljs$lang$applyTo = G__45211__2.cljs$lang$applyTo;
G__45211.cljs$core$IFn$_invoke$arity$0 = G__45211__0;
G__45211.cljs$core$IFn$_invoke$arity$1 = G__45211__1;
G__45211.cljs$core$IFn$_invoke$arity$variadic = G__45211__2.cljs$core$IFn$_invoke$arity$variadic;
return G__45211;
})()
});
dv.cljs_emotion.global_STAR_ = dv.cljs_emotion.react_factory(module$node_modules$$emotion$react$dist$emotion_react_browser_cjs.Global,null);
dv.cljs_emotion.global_style = (function dv$cljs_emotion$global_style(props){
return dv.cljs_emotion.global_STAR_(new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"styles","styles",1954480375),dv.cljs_emotion.camelize_keys(props)], null));
});
dv.cljs_emotion.theme_provider = (function dv$cljs_emotion$theme_provider(var_args){
var args__4742__auto__ = [];
var len__4736__auto___45230 = arguments.length;
var i__4737__auto___45231 = (0);
while(true){
if((i__4737__auto___45231 < len__4736__auto___45230)){
args__4742__auto__.push((arguments[i__4737__auto___45231]));

var G__45232 = (i__4737__auto___45231 + (1));
i__4737__auto___45231 = G__45232;
continue;
} else {
}
break;
}

var argseq__4743__auto__ = ((((1) < args__4742__auto__.length))?(new cljs.core.IndexedSeq(args__4742__auto__.slice((1)),(0),null)):null);
return dv.cljs_emotion.theme_provider.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__4743__auto__);
});

(dv.cljs_emotion.theme_provider.cljs$core$IFn$_invoke$arity$variadic = (function (props,children){
if(cljs.core.contains_QMARK_(props,new cljs.core.Keyword(null,"theme","theme",-1247880880))){
} else {
throw (new Error("You must pass a :theme to the theme-provider."));
}

return cljs.core.apply.cljs$core$IFn$_invoke$arity$4(module$node_modules$react$index.createElement,module$node_modules$$emotion$react$dist$emotion_react_browser_cjs.ThemeProvider,cljs.core.clj__GT_js(props),dv.cljs_emotion.force_children(children));
}));

(dv.cljs_emotion.theme_provider.cljs$lang$maxFixedArity = (1));

/** @this {Function} */
(dv.cljs_emotion.theme_provider.cljs$lang$applyTo = (function (seq45152){
var G__45155 = cljs.core.first(seq45152);
var seq45152__$1 = cljs.core.next(seq45152);
var self__4723__auto__ = this;
return self__4723__auto__.cljs$core$IFn$_invoke$arity$variadic(G__45155,seq45152__$1);
}));


//# sourceMappingURL=dv.cljs_emotion.js.map
